==> apache-storm-2.3.0-src.tar.gz: apache-storm-2.3.0/storm-client/test/jvm/org/apache/storm/daemon/worker/WorkerTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.daemon.worker;

import org.apache.storm.messaging.ConnectionWithStatus;
import org.junit.Test;
import org.mockito.Mockito;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class WorkerTest {
    @Test
    public void testWorkerIsConnectionReady() {
        ConnectionWithStatus connection = Mockito.mock(ConnectionWithStatus.class);
        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Ready);
        assertTrue(WorkerState.isConnectionReady(connection));

        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Connecting);
        assertFalse(WorkerState.isConnectionReady(connection));

        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Closed);
        assertFalse(WorkerState.isConnectionReady(connection));
    }
}

==> apache-storm-2.6.2-src.tar.gz: apache-storm-2.6.2/storm-client/test/jvm/org/apache/storm/daemon/worker/WorkerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.daemon.worker;

import org.apache.storm.messaging.ConnectionWithStatus;
import org.junit.jupiter.api.Test;
import org.mockito.Mockito;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class WorkerTest {
    @Test
    public void testWorkerIsConnectionReady() {
        ConnectionWithStatus connection = Mockito.mock(ConnectionWithStatus.class);
        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Ready);
        assertTrue(WorkerState.isConnectionReady(connection));

        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Connecting);
        assertFalse(WorkerState.isConnectionReady(connection));

        Mockito.when(connection.status()).thenReturn(ConnectionWithStatus.Status.Closed);
        assertFalse(WorkerState.isConnectionReady(connection));
    }
}
